@@ -22,6 +22,7 @@ import (
 	"errors"
 	"fmt"
 	"io/ioutil"
+	"os"
 	"path/filepath"
 	"testing"
 
@@ -408,7 +409,8 @@ spec:
 			},
 			KubeContext: testKubeContext,
 			Opts: config.SkaffoldOptions{
-				Namespace: testNamespace,
+				Namespace:         testNamespace,
+				AddSkaffoldLabels: true,
 			},
 		})
 
@@ -630,12 +632,67 @@ spec:
 					},
 				},
 				KubeContext: testKubeContext,
-				Opts:        config.SkaffoldOptions{DefaultRepo: defaultRepo},
+				Opts: config.SkaffoldOptions{
+					AddSkaffoldLabels: true,
+					DefaultRepo:       defaultRepo,
+				},
 			})
 			var b bytes.Buffer
-			err := deployer.Render(context.Background(), &b, test.builds, test.labels, "")
+			err := deployer.Render(context.Background(), &b, test.builds, test.labels, true, "")
 			t.CheckNoError(err)
 			t.CheckDeepEqual(test.expected, b.String())
 		})
 	}
 }
+
+func TestGCSManifests(t *testing.T) {
+	tests := []struct {
+		description string
+		cfg         *latest.KubectlDeploy
+		commands    util.Command
+		shouldErr   bool
+		skipRender  bool
+	}{
+		{
+			description: "manifest from GCS",
+			cfg: &latest.KubectlDeploy{
+				Manifests: []string{"gs://dev/deployment.yaml"},
+			},
+			commands: testutil.
+				CmdRunOut(fmt.Sprintf("gsutil cp -r %s %s", "gs://dev/deployment.yaml", manifestTmpDir), "log").
+				AndRunOut("kubectl version --client -ojson", kubectlVersion112).
+				AndRunOut("kubectl --context kubecontext --namespace testNamespace create --dry-run -oyaml -f "+filepath.Join(manifestTmpDir, "deployment.yaml"), deploymentWebYAML).
+				AndRun("kubectl --context kubecontext --namespace testNamespace apply -f -"),
+			skipRender: true,
+		}}
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			t.Override(&util.DefaultExecCommand, test.commands)
+			if err := os.MkdirAll(manifestTmpDir, os.ModePerm); err != nil {
+				t.Fatal(err)
+			}
+			if err := ioutil.WriteFile(manifestTmpDir+"/deployment.yaml", []byte(deploymentWebYAML), os.ModePerm); err != nil {
+				t.Fatal(err)
+			}
+			k := NewKubectlDeployer(&runcontext.RunContext{
+				WorkingDir: ".",
+				Cfg: latest.Pipeline{
+					Deploy: latest.DeployConfig{
+						DeployType: latest.DeployType{
+							KubectlDeploy: test.cfg,
+						},
+					},
+				},
+				KubeContext: testKubeContext,
+				Opts: config.SkaffoldOptions{
+					Namespace:  testNamespace,
+					SkipRender: test.skipRender,
+				},
+			})
+
+			err := k.Deploy(context.Background(), ioutil.Discard, nil, nil).GetError()
+
+			t.CheckError(test.shouldErr, err)
+		})
+	}
+}
