@@ -30,6 +30,7 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	deploy "github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/kubectl"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
@@ -44,6 +45,7 @@ import (
 var (
 	DefaultKustomizePath = "."
 	kustomizeFilePaths   = []string{"kustomization.yaml", "kustomization.yml", "Kustomization"}
+	basePath             = "base"
 )
 
 type patchPath struct {
@@ -90,6 +92,8 @@ type KustomizeDeployer struct {
 	kubectl            deploy.CLI
 	insecureRegistries map[string]bool
 	BuildArgs          []string
+	globalConfig       string
+	addSkaffoldLabels  bool
 }
 
 func NewKustomizeDeployer(runCtx *runcontext.RunContext) *KustomizeDeployer {
@@ -102,6 +106,8 @@ func NewKustomizeDeployer(runCtx *runcontext.RunContext) *KustomizeDeployer {
 		},
 		insecureRegistries: runCtx.InsecureRegistries,
 		BuildArgs:          runCtx.Cfg.Deploy.KustomizeDeploy.BuildArgs,
+		globalConfig:       runCtx.Opts.GlobalConfig,
+		addSkaffoldLabels:  runCtx.Opts.AddSkaffoldLabels,
 	}
 }
 
@@ -148,6 +154,11 @@ func (k *KustomizeDeployer) renderManifests(ctx context.Context, out io.Writer,
 		color.Default.Fprintln(out, err)
 	}
 
+	debugHelpersRegistry, err := config.GetDebugHelpersRegistry(k.globalConfig)
+	if err != nil {
+		return nil, fmt.Errorf("retrieving debug helpers registry: %w", err)
+	}
+
 	manifests, err := k.readManifests(ctx)
 	if err != nil {
 		return nil, fmt.Errorf("reading manifests: %w", err)
@@ -163,13 +174,13 @@ func (k *KustomizeDeployer) renderManifests(ctx context.Context, out io.Writer,
 	}
 
 	for _, transform := range manifestTransforms {
-		manifests, err = transform(manifests, builds, k.insecureRegistries)
+		manifests, err = transform(manifests, builds, Registries{k.insecureRegistries, debugHelpersRegistry})
 		if err != nil {
 			return nil, fmt.Errorf("unable to transform manifests: %w", err)
 		}
 	}
 
-	manifests, err = manifests.SetLabels(merge(k, labellers...))
+	manifests, err = manifests.SetLabels(merge(k.addSkaffoldLabels, k, labellers...))
 	if err != nil {
 		return nil, fmt.Errorf("setting labels in manifests: %w", err)
 	}
@@ -204,25 +215,12 @@ func (k *KustomizeDeployer) Dependencies() ([]string, error) {
 	return deps.toList(), nil
 }
 
-func (k *KustomizeDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller, filepath string) error {
+func (k *KustomizeDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller, offline bool, filepath string) error {
 	manifests, err := k.renderManifests(ctx, out, builds, labellers)
 	if err != nil {
 		return err
 	}
-
-	manifestOut := out
-	if filepath != "" {
-		f, err := os.OpenFile(filepath, os.O_RDWR|os.O_CREATE, 0666)
-		if err != nil {
-			return fmt.Errorf("opening file for writing manifests: %w", err)
-		}
-		defer f.Close()
-		f.WriteString(manifests.String() + "\n")
-		return nil
-	}
-
-	fmt.Fprintln(manifestOut, manifests.String())
-	return nil
+	return outputRenderedManifests(manifests.String(), filepath, out)
 }
 
 // UnmarshalYAML implements JSON unmarshalling by reading an inline yaml fragment.
@@ -264,7 +262,7 @@ func dependenciesForKustomization(dir string) ([]string, error) {
 	candidates := append(content.Bases, content.Resources...)
 
 	for _, candidate := range candidates {
-		// If the file  doesn't exist locally, we can assume it's a remote file and
+		// If the file doesn't exist locally, we can assume it's a remote file and
 		// skip it, since we can't monitor remote files. Kustomize itself will
 		// handle invalid/missing files.
 		local, mode := pathExistsLocally(candidate, dir)
@@ -316,8 +314,7 @@ func dependenciesForKustomization(dir string) ([]string, error) {
 // A Kustomization config must be at the root of the directory. Kustomize will
 // error if more than one of these files exists so order doesn't matter.
 func findKustomizationConfig(dir string) (string, error) {
-	candidates := []string{"kustomization.yaml", "kustomization.yml", "Kustomization"}
-	for _, candidate := range candidates {
+	for _, candidate := range kustomizeFilePaths {
 		if local, _ := pathExistsLocally(candidate, dir); local {
 			return filepath.Join(dir, candidate), nil
 		}
@@ -371,6 +368,10 @@ func buildCommandArgs(buildArgs []string, kustomizePath string) []string {
 	return args
 }
 
+func IsKustomizationBase(path string) bool {
+	return filepath.Dir(path) == basePath
+}
+
 func IsKustomizationPath(path string) bool {
 	filename := filepath.Base(path)
 	for _, candidate := range kustomizeFilePaths {
