@@ -87,28 +87,6 @@ func TestKustomizeDeploy(t *testing.T) {
 			},
 			forceDeploy: true,
 		},
-		{
-			description: "built-in kubectl kustomize with newer version",
-			cfg: &latest.KustomizeDeploy{
-				KustomizePaths: []string{"a", "b"},
-			},
-			commands: testutil.
-				CmdRunOut("kubectl version --client -ojson", kubectlVersion118).
-				AndRunOut("kubectl --context kubecontext --namespace testNamespace kustomize a", deploymentWebYAML).
-				AndRunOut("kubectl --context kubecontext --namespace testNamespace kustomize b", deploymentAppYAML).
-				AndRun("kubectl --context kubecontext --namespace testNamespace apply -f - --force --grace-period=0"),
-			builds: []build.Artifact{
-				{
-					ImageName: "leeroy-web",
-					Tag:       "leeroy-web:123",
-				},
-				{
-					ImageName: "leeroy-app",
-					Tag:       "leeroy-app:123",
-				},
-			},
-			forceDeploy: true,
-		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
@@ -153,8 +131,7 @@ func TestKustomizeCleanup(t *testing.T) {
 				KustomizePaths: []string{tmpDir.Root()},
 			},
 			commands: testutil.
-				CmdRunOut("kubectl version --client -ojson", kubectlVersion112).
-				AndRunOut("kustomize build "+tmpDir.Root(), deploymentWebYAML).
+				CmdRunOut("kustomize build "+tmpDir.Root(), deploymentWebYAML).
 				AndRun("kubectl --context kubecontext --namespace testNamespace delete --ignore-not-found=true -f -"),
 		},
 		{
@@ -163,8 +140,7 @@ func TestKustomizeCleanup(t *testing.T) {
 				KustomizePaths: tmpDir.Paths("a", "b"),
 			},
 			commands: testutil.
-				CmdRunOut("kubectl version --client -ojson", kubectlVersion112).
-				AndRunOut("kustomize build "+tmpDir.Path("a"), deploymentWebYAML).
+				CmdRunOut("kustomize build "+tmpDir.Path("a"), deploymentWebYAML).
 				AndRunOut("kustomize build "+tmpDir.Path("b"), deploymentAppYAML).
 				AndRun("kubectl --context kubecontext --namespace testNamespace delete --ignore-not-found=true -f -"),
 		},
@@ -174,8 +150,7 @@ func TestKustomizeCleanup(t *testing.T) {
 				KustomizePaths: []string{tmpDir.Root()},
 			},
 			commands: testutil.
-				CmdRunOut("kubectl version --client -ojson", kubectlVersion112).
-				AndRunOut("kustomize build "+tmpDir.Root(), deploymentWebYAML).
+				CmdRunOut("kustomize build "+tmpDir.Root(), deploymentWebYAML).
 				AndRunErr("kubectl --context kubecontext --namespace testNamespace delete --ignore-not-found=true -f -", errors.New("BUG")),
 			shouldErr: true,
 		},
@@ -184,9 +159,11 @@ func TestKustomizeCleanup(t *testing.T) {
 			cfg: &latest.KustomizeDeploy{
 				KustomizePaths: []string{tmpDir.Root()},
 			},
-			commands: testutil.
-				CmdRunOut("kubectl version --client -ojson", kubectlVersion112).
-				AndRunOutErr("kustomize build "+tmpDir.Root(), "", errors.New("BUG")),
+			commands: testutil.CmdRunOutErr(
+				"kustomize build "+tmpDir.Root(),
+				"",
+				errors.New("BUG"),
+			),
 			shouldErr: true,
 		},
 	}
@@ -422,49 +399,49 @@ func TestKustomizeBuildCommandArgs(t *testing.T) {
 			description:   "no BuildArgs, empty KustomizePaths ",
 			buildArgs:     []string{},
 			kustomizePath: "",
-			expectedArgs:  nil,
+			expectedArgs:  []string{"build"},
 		},
 		{
 			description:   "One BuildArg, empty KustomizePaths",
 			buildArgs:     []string{"--foo"},
 			kustomizePath: "",
-			expectedArgs:  []string{"--foo"},
+			expectedArgs:  []string{"build", "--foo"},
 		},
 		{
 			description:   "no BuildArgs, non-empty KustomizePaths",
 			buildArgs:     []string{},
 			kustomizePath: "foo",
-			expectedArgs:  []string{"foo"},
+			expectedArgs:  []string{"build", "foo"},
 		},
 		{
 			description:   "One BuildArg, non-empty KustomizePaths",
 			buildArgs:     []string{"--foo"},
 			kustomizePath: "bar",
-			expectedArgs:  []string{"--foo", "bar"},
+			expectedArgs:  []string{"build", "--foo", "bar"},
 		},
 		{
 			description:   "Multiple BuildArg, empty KustomizePaths",
 			buildArgs:     []string{"--foo", "--bar"},
 			kustomizePath: "",
-			expectedArgs:  []string{"--foo", "--bar"},
+			expectedArgs:  []string{"build", "--foo", "--bar"},
 		},
 		{
 			description:   "Multiple BuildArg with spaces, empty KustomizePaths",
 			buildArgs:     []string{"--foo bar", "--baz"},
 			kustomizePath: "",
-			expectedArgs:  []string{"--foo", "bar", "--baz"},
+			expectedArgs:  []string{"build", "--foo", "bar", "--baz"},
 		},
 		{
 			description:   "Multiple BuildArg with spaces, non-empty KustomizePaths",
 			buildArgs:     []string{"--foo bar", "--baz"},
 			kustomizePath: "barfoo",
-			expectedArgs:  []string{"--foo", "bar", "--baz", "barfoo"},
+			expectedArgs:  []string{"build", "--foo", "bar", "--baz", "barfoo"},
 		},
 		{
 			description:   "Multiple BuildArg no spaces, non-empty KustomizePaths",
 			buildArgs:     []string{"--foo", "bar", "--baz"},
 			kustomizePath: "barfoo",
-			expectedArgs:  []string{"--foo", "bar", "--baz", "barfoo"},
+			expectedArgs:  []string{"build", "--foo", "bar", "--baz", "barfoo"},
 		},
 	}
 
@@ -675,11 +652,12 @@ spec:
 				},
 				KubeContext: testKubeContext,
 				Opts: config.SkaffoldOptions{
-					Namespace: testNamespace,
+					Namespace:         testNamespace,
+					AddSkaffoldLabels: true,
 				},
 			})
 			var b bytes.Buffer
-			err := k.Render(context.Background(), &b, test.builds, test.labels, "")
+			err := k.Render(context.Background(), &b, test.builds, test.labels, true, "")
 			t.CheckError(test.shouldErr, err)
 			t.CheckDeepEqual(test.expected, b.String())
 		})
