@@ -25,12 +25,12 @@ type Error string
 
 func (e Error) Error() string { return string(e) }
 
-const NoManifest = Error("one or more Kubernetes manifests are required to run skaffold")
+const NoManifest = Error("one or more valid Kubernetes manifests are required to run skaffold")
 
 // Initializer detects a deployment type and is able to extract image names from it
 type Initializer interface {
 	// deployConfig generates Deploy Config for skaffold configuration.
-	DeployConfig() latest.DeployConfig
+	DeployConfig() (latest.DeployConfig, []latest.Profile)
 	// GetImages fetches all the images defined in the manifest files.
 	GetImages() []string
 	// Validate ensures preconditions are met before generating a skaffold config
@@ -43,14 +43,14 @@ type cliDeployInit struct {
 	cliKubernetesManifests []string
 }
 
-func (c *cliDeployInit) DeployConfig() latest.DeployConfig {
+func (c *cliDeployInit) DeployConfig() (latest.DeployConfig, []latest.Profile) {
 	return latest.DeployConfig{
 		DeployType: latest.DeployType{
 			KubectlDeploy: &latest.KubectlDeploy{
 				Manifests: c.cliKubernetesManifests,
 			},
 		},
-	}
+	}, nil
 }
 
 func (c *cliDeployInit) GetImages() []string {
@@ -69,8 +69,8 @@ func (c *cliDeployInit) AddManifestForImage(string, string) {}
 type emptyDeployInit struct {
 }
 
-func (e *emptyDeployInit) DeployConfig() latest.DeployConfig {
-	return latest.DeployConfig{}
+func (e *emptyDeployInit) DeployConfig() (latest.DeployConfig, []latest.Profile) {
+	return latest.DeployConfig{}, nil
 }
 
 func (e *emptyDeployInit) GetImages() []string {
@@ -86,14 +86,14 @@ func (e *emptyDeployInit) AddManifestForImage(string, string) {}
 // if any CLI manifests are provided, we always use those as part of a kubectl deploy first
 // if not, then if a kustomization yaml is found, we use that next
 // otherwise, default to a kubectl deploy.
-func NewInitializer(manifests []string, kustomizations []string, c config.Config) Initializer {
+func NewInitializer(manifests, bases, kustomizations []string, c config.Config) Initializer {
 	switch {
 	case c.SkipDeploy:
 		return &emptyDeployInit{}
 	case len(c.CliKubernetesManifests) > 0:
 		return &cliDeployInit{c.CliKubernetesManifests}
 	case len(kustomizations) > 0:
-		return newKustomizeInitializer(kustomizations, manifests)
+		return newKustomizeInitializer(c.DefaultKustomization, bases, kustomizations, manifests)
 	default:
 		return newKubectlInitializer(manifests)
 	}
